@@ -1,6 +1,7 @@
 # apache2 -- lintian check script -*- perl -*-
 #
 # Copyright © 2012 Arno Töll
+# Copyright © 2017-2018 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,14 +21,14 @@
 
 package Lintian::apache2;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use File::Basename;
 
 use Lintian::Relation qw(:constants);
-use Lintian::Util qw(internal_error);
 
 use Moo;
 use namespace::clean;
@@ -95,7 +96,7 @@ sub files {
     return;
 }
 
-sub binary {
+sub installable {
     my ($self) = @_;
 
     # Do nothing if the package in question appears to be related to
