@@ -1,7 +1,8 @@
 # debian/rules -- lintian check script -*- perl -*-
 
-# Copyright (C) 2006 Russ Allbery <rra@debian.org>
-# Copyright (C) 2005 René van Bevern <rvb@pro-linux.de>
+# Copyright © 2006 Russ Allbery <rra@debian.org>
+# Copyright © 2005 René van Bevern <rvb@pro-linux.de>
+# Copyright © 2019-2020 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,8 +16,9 @@
 
 package Lintian::debian::rules;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Carp qw(croak);
@@ -24,7 +26,6 @@ use List::MoreUtils qw(any none);
 
 use Lintian::Data;
 use Lintian::SlidingWindow;
-use Lintian::Util qw(rstrip);
 
 use Moo;
 use namespace::clean;
@@ -40,6 +41,8 @@ our $PYTHON3X_DEPEND= join(' | ',
     map { "python${_}:any | python${_}-dev:any" } qw(3.4 3.5 3.6 3.7));
 our $ANYPYTHON_DEPEND
   = "$PYTHON_DEPEND | $PYTHON2X_DEPEND | $PYTHON3_DEPEND | $PYTHON3X_DEPEND";
+our $PYTHON3_ALL_DEPEND
+  = 'python3-all:any | python3-all-dev:any | python3-all-dbg:any';
 
 my $KNOWN_MAKEFILES = Lintian::Data->new('rules/known-makefiles', '\|\|');
 my $DEPRECATED_MAKEFILES = Lintian::Data->new('rules/deprecated-makefiles');
@@ -141,7 +144,7 @@ sub source {
     my $processable = $self->processable;
     my $group = $self->group;
 
-    my $debian_dir = $processable->index_resolved_path('debian');
+    my $debian_dir = $processable->patched->resolve_path('debian');
     my $rules;
     $rules = $debian_dir->child('rules') if $debian_dir;
 
@@ -162,7 +165,7 @@ sub source {
     # If the version field is missing, we assume a neutral non-native one.
     $version = '0-1' unless defined $version;
 
-    my $rules_fd = $rules->open;
+    open(my $rules_fd, '<', $rules->unpacked_path);
 
     # Check for required #!/usr/bin/make -f opening line.  Allow -r or -e; a
     # strict reading of Policy doesn't allow either, but they seem harmless.
@@ -267,6 +270,18 @@ sub source {
             }
         }
 
+        if ($line =~ m/--as-needed/ and $line !~ m/--no-as-needed/) {
+            $self->tag('debian-rules-uses-as-needed-linker-flag',"line $.");
+        }
+
+        #<<< no Perl tidy
+        $self->tag(
+            'debian-rules-uses-supported-python-versions-without-python-all-build-depends',
+            $1, "(line $.)"
+        ) if $line =~ m/(py3versions\s+([\w\-\s]*--supported|-\w*s\w*))/
+          and not $build_all->implies($PYTHON3_ALL_DEPEND);
+        #>>>
+
         # General assignment - save the variable
         if (/^\s*(?:\S+\s+)*?(\S+)\s*[:\?\+]?=\s*(.*+)?$/so) {
             # This is far too simple from a theoretical PoV, but should do
@@ -316,7 +331,9 @@ sub source {
                         # we think we know what it will expand to - note
                         # we ought to "delay" it was a "=" variable rather
                         # than ":=" or "+=".
-                        for (split m/\s++/o, rstrip($val)) {
+
+                   # discards empty elements at end, effectively trimming right
+                        for (split(/\s+/, $val)) {
                             $seen{$_}++ if $POLICYRULES->known($_);
                         }
                         last;
@@ -359,7 +376,9 @@ sub source {
                             # we ought to "delay" it was a "=" variable rather
                             # than ":=" or "+=".
                             local $_;
-                            for (split m/\s++/o, rstrip($val)) {
+
+                   # discards empty elements at end, effectively trimming right
+                            for (split(/\s+/, $val)) {
                                 $seen{$_}++ if $POLICYRULES->known($_);
                             }
                             last;
@@ -516,7 +535,7 @@ sub source {
         }
     }
 
-    $rules_fd = $rules->open;
+    open($rules_fd, '<', $rules->unpacked_path);
     my $sfd = Lintian::SlidingWindow->new($rules_fd);
     my $block;
     while ($block = $sfd->readwindow) {
