@@ -3,8 +3,9 @@
 # This is probably the right file to add a check for the use of
 # set -e in bash and sh scripts.
 #
-# Copyright (C) 1998 Richard Braakman
-# Copyright (C) 2002 Josip Rodin
+# Copyright © 1998 Richard Braakman
+# Copyright © 2002 Josip Rodin
+# Copyright © 2016-2019 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,8 +25,9 @@
 
 package Lintian::scripts;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Capture::Tiny qw(capture);
@@ -36,7 +38,9 @@ use Try::Tiny;
 use Lintian::Spelling qw($known_shells_regex);
 use Lintian::Data;
 use Lintian::Relation;
-use Lintian::Util qw(safe_qx strip);
+use Lintian::Util qw(safe_qx);
+
+use constant EMPTY => q{};
 
 use Moo;
 use namespace::clean;
@@ -111,21 +115,36 @@ my $BAD_MAINT_CMD = Lintian::Data->new(
         }
         my ($incat,$inauto,$exceptinpackage,$inscript,$regexp) = @sliptline;
         $regexp =~ s/\$[{]LEADIN[}]/$LEADINSTR/;
+
+        $incat //= EMPTY;
+        $inauto //= EMPTY;
+
+        # trim both ends
+        $incat =~ s/^\s+|\s+$//g;
+        $inauto =~ s/^\s+|\s+$//g;
+
    # allow empty $exceptinpackage and set it synonymous to check in all package
-        $exceptinpackage
-          = defined($exceptinpackage) ? strip($exceptinpackage) : '';
+        $exceptinpackage //= EMPTY;
+
+        # trim both ends
+        $exceptinpackage =~ s/^\s+|\s+$//g;
+
         if (length($exceptinpackage) == 0) {
             $exceptinpackage = '\a\Z';
         }
         # allow empty $inscript and set to synonymous to check in all script
-        $inscript = defined($inscript) ? strip($inscript) : '';
+        $inscript //= EMPTY;
+
+        # trim both ends
+        $inscript =~ s/^\s+|\s+$//g;
+
         if (length($inscript) == 0) {
             $inscript = '.*';
         }
         return {
             # use not not to normalize boolean
-            'ignore_automatically_added' => not(not(strip($inauto))),
-            'in_cat_string' => not(not(strip($incat))),
+            'ignore_automatically_added' => not(not($inauto)),
+            'in_cat_string' => not(not($incat)),
             'in_package' => qr/$exceptinpackage/x,
             'in_script' => qr/$inscript/x,
             'regexp' => qr/$regexp/x,
@@ -1152,8 +1171,8 @@ m,$LEADIN(?:/usr/bin/)?dpkg\s+--compare-versions\s+.*\b\Q$ver\E(?!\.)\b,
                 # remove the leading / because it's not in the index hash
                 $divert =~ s,^/,,;
 
-                # remove any remaining leading or trailing whitespace.
-                strip($divert);
+                # trim both ends
+                $divert =~ s/^\s+|\s+$//g;
 
                 $divert = quotemeta($divert);
 
