@@ -2,8 +2,9 @@
 #
 # Lintian HTML reporting tool -- Create Lintian web reports
 #
-# Copyright (C) 1998 Christian Schwarz and Richard Braakman
-# Copyright (C) 2007 Russ Allbery
+# Copyright © 1998 Christian Schwarz and Richard Braakman
+# Copyright © 2007 Russ Allbery
+# Copyright © 2017-2019 Chris Lamb <lamby@debian.org>
 #
 # This program is free software.  It is distributed under the terms of
 # the GNU General Public License as published by the Free Software
@@ -21,8 +22,9 @@
 # Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301, USA.
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Getopt::Long;
@@ -36,7 +38,6 @@ use Text::Template ();
 use URI::Escape;
 use YAML::XS ();
 
-use Lintian::Command qw(safe_qx);
 use Lintian::Data;
 use Lintian::Deb822Parser qw(read_dpkg_control);
 use Lintian::Internal::FrontendUtil qw(split_tag);
@@ -44,7 +45,7 @@ use Lintian::Profile;
 use Lintian::Relation::Version qw(versions_comparator);
 use Lintian::Reporting::ResourceManager;
 use Lintian::Reporting::Util qw(load_state_cache find_backlog);
-use Lintian::Util qw(copy_dir run_cmd check_path);
+use Lintian::Util qw(copy_dir run_cmd check_path safe_qx);
 
 my $CONFIG;
 my %OPT;
