@@ -1,4 +1,5 @@
 # Copyright © 2018 Felix Lechner
+# Copyright © 2019 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,10 +37,10 @@ Generic test runner for all Lintian test suites
 
 =cut
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
-use v5.10;
 
 use Exporter qw(import);
 
